{
  config,
  lib,
  pkgs,
  ...
}: {
  imports = [
    ./hardware-configuration.nix

    "${builtins.fetchTarball {
      url = "https://github.com/nix-community/disko/archive/refs/tags/v1.5.0.tar.gz";
      sha256 = "sha256:1d03a0wb710by1m2c3rx758vy67f8r71gnv2h3qn4jj1bx10sdg4";
    }}/module.nix"
    ./disko.nix

    ./firewall.nix
    ./kanata.nix
  ];

  boot.loader.systemd-boot.enable = true;
  boot.loader.efi.canTouchEfiVariables = true;

  networking.hostName = "kelly";
  networking.networkmanager.enable = true;
  time.timeZone = "Europe/Athens";

  system.copySystemConfiguration = false;
  system.stateVersion = "23.11";

  programs.fish.enable = true;
  users.users.gkaklas = {
    isNormalUser = true;
    extraGroups = ["wheel" "uinput"];
    shell = pkgs.fish;
  };
  users.users.gkaklas.openssh.authorizedKeys.keys = [
    "ssh-ed25519 AAAAC3NzaC1lZDI1NTE5AAAAIHRvzNjXbCJ1/lIcZXdJSzkadYOIoAzZ2G2stoxZY7qz gkaklas@onyx"
  ];
  #users.groups.uinput = {};
  security.sudo.wheelNeedsPassword = false;
  security.pam.services.gkaklas.kwallet.enable = true;

  services.xserver.enable = true;
  services.desktopManager.plasma6.enable = true;
  services.displayManager = {
    sddm.enable = true;
    sddm.autoLogin.relogin = true;
    autoLogin.enable = true;
    autoLogin.user = "gkaklas";
    defaultSession = "plasma";
    sddm.wayland.enable = true;
  };

  services = {
    openssh.enable = true;
    openssh.settings.PasswordAuthentication = false;

    pipewire.enable = true;
    pipewire.pulse.enable = true;

    flatpak.enable = true;
    fprintd.enable = true;
    fwupd.enable = true;
  };

  hardware = {
    bluetooth.enable = true;
    sensor.iio.enable = true;
  };

  powerManagement.enable = true;
  xdg.portal.enable = true;

  virtualisation.podman.enable = true;

  nix = {
    package = pkgs.nixFlakes;
    extraOptions = ''
      experimental-features = nix-command flakes
    '';
  };
}
